<?php
/**
 * Plugin Name: WP Knowledgebase
 * Plugin URI: http://wordpress.org/plugins/wp-knowledgebase
 * Description: Simple and flexible knowledgebase plugin for WordPress
 * Version: 1.2.3
 * Author: Mihai Iova
 * Author URI: https://usewpknowledgebase.com/
 * Text Domain: wp-knowledgebase
 * License: GPL2
 *
 * == Copyright ==
 * Copyright 2020 WP Knowledgebase
 *	
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'KBE_PLUGIN_VERSION', '1.2.3' );

//=========> Create language folder
function kbe_plugin_load_textdomain() {

	$locale = apply_filters( 'plugin_locale', get_locale(), 'wp-knowledgebase' );

	// Load textdomain
	load_textdomain( 'wp-knowledgebase', WP_LANG_DIR . '/wp-knowledgebase/wp-knowledgebase-' . $locale . '.mo' );
	load_plugin_textdomain( 'wp-knowledgebase', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

}
add_action( 'init', 'kbe_plugin_load_textdomain' );

//  Require File kbe_articles.php
require 'includes/kbe-articles.php';
require 'includes/kbe-template-functions.php';
require 'includes/kbe-core-functions.php';

//  Require Category Widget file
require 'includes/widgets/kbe-widget-category.php';
//  Require Articles Widget file
require 'includes/widgets/kbe-widget-article.php';
//  Require Search Articles Widget file
require 'includes/widgets/kbe-widget-search.php';
//  Require Tags Widget file
require 'includes/widgets/kbe-widget-tags.php';


// Include update checker
require 'includes/class-update-checker.php';


// Include admin file(s)
if ( is_admin() && ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) ) {
	require 'includes/admin/kbe-admin-functions.php';
	//require 'includes/admin/functions-promo.php';
}

if( is_admin() ) {
	require 'includes/admin/functions-actions-ajax.php';
}


//=========> Define plugin path
define( 'WP_KNOWLEDGEBASE', plugin_dir_url( __FILE__ ) );
define( 'KBE_ARTICLE_QTY', get_option( 'kbe_article_qty' ) );
define( 'KBE_PLUGIN_SLUG', get_option( 'kbe_plugin_slug' ) );
define( 'KBE_SEARCH_SETTING', get_option( 'kbe_search_setting' ) );
define( 'KBE_BREADCRUMBS_SETTING', get_option( 'kbe_breadcrumbs_setting' ) );
define( 'KBE_SIDEBAR_HOME', get_option( 'kbe_sidebar_home' ) );
define( 'KBE_SIDEBAR_INNER', get_option( 'kbe_sidebar_inner' ) );
define( 'KBE_COMMENT_SETTING', get_option( 'kbe_comments_setting' ) );
define( 'KBE_BG_COLOR', get_option( 'kbe_bgcolor' ) );
define( 'KBE_LINK_STRUCTURE', get_option( 'permalink_structure' ) );
define( 'KBE_POST_TYPE', 'kbe_knowledgebase' );
define( 'KBE_POST_TAXONOMY', 'kbe_taxonomy' );
define( 'KBE_POST_TAGS', 'kbe_tags' );
define( 'KBE_PAGE_TITLE', kbe_get_knowledgebase_page_id() );

require 'includes/migrations/class-abstract-migration.php';
require 'includes/migrations/migration-install.php';

// Include the deactivation class
require 'includes/class-deactivation.php';